import request from '@/utils/request'

/**
 * 授权账号列表（分页）
 * @param data
 * @returns {*}
 */
export function getList(data) {
  return request({
    url: '/api/v1/auth/account/page',
    method: 'post',
    headers: { 'content-type': 'application/json' },
    data
  })
}

/**
 * 获取登录账号信息
 * @returns {*}
 */
export function getAccountAuthQuery() {
  return request({
    url: `/api/v1/auth/account/query`,
    method: 'post'
  })
}

/**
 * 授权账号列表
 * @returns {*}
 */
export function getAccountList() {
  return request({
    url: `/api/v1/auth/account/list`,
    method: 'post'
  })
}

/**
 * 添加或编辑授权账号
 * @param data
 * @returns {*}
 */
export function addOrUpdateAuthAccount(data) {
  return request({
    url: '/api/v1/auth/account/add',
    method: 'post',
    headers: { 'content-type': 'application/json' },
    data
  })
}

/**
 * 删除授权账号
 * @param id
 * @returns {*}
 */
export function deleteById(id) {
  return request({
    url: `/api/v1/auth/account/del/${id}`,
    method: 'post'
  })
}

/**
 * 查询授权模块枚举列表
 * @returns {*}
 */
export function getAccountAuthTypeList() {
  return request({
    url: `/api/v1/auth/account/module/type/list`,
    method: 'post'
  })
}

/**
 * 查询系统配置枚举列表
 * @returns {*}
 */
export function getAccountAuthSysConfigList() {
  return request({
    url: `/api/v1/auth/account/system/config/list`,
    method: 'post'
  })
}

/**
 * 查询使用配置枚举列表
 * @returns {*}
 */
export function getAccountAuthUseConfigList() {
  return request({
    url: `/api/v1/auth/account/use/config/list`,
    method: 'post'
  })
}

/**
 * 查询推送配置枚举列表
 * @returns {*}
 */
export function getAccountAuthPushConfigList() {
  return request({
    url: `/api/v1/auth/account/push/config/list`,
    method: 'post'
  })
}

/**
 * 查询HHFace权限配置-使用配置枚举列表
 * @returns {*}
 */
export function getAccountHHFaceUseConfigList() {
  return request({
    url: `/api/v1/auth/account/hhface/use/config/list`,
    method: 'post'
  })
}

/**
 * 查询HHFace权限配置-支付宝人脸采集配置枚举列表
 * @returns {*}
 */
export function getAccountHHFaceFaceConfigList() {
  return request({
    url: `/api/v1/auth/account/hhface/face/config/list`,
    method: 'post'
  })
}

/**
 * 查询HHFace权限配置-采集配置枚举列表
 * @returns {*}
 */
export function getAccountHHFaceCollectConfigList() {
  return request({
    url: `/api/v1/auth/account/hhface/collect/config/list`,
    method: 'post'
  })
}

/**
 * 查询HHFace权限配置-三方接口配置枚举列表
 * @returns {*}
 */
export function getAccountHHFaceThirdConfigList() {
  return request({
    url: `/api/v1/auth/account/hhface/third/config/list`,
    method: 'post'
  })
}

/**
 * 查询HHFace权限配置-结果页配置枚举列表
 * @returns {*}
 */
export function getAccountHHFaceResultConfigList() {
  return request({
    url: `/api/v1/auth/account/hhface/result/config/list`,
    method: 'post'
  })
}

/**
 * 查询HHFace权限配置-硬件配置枚举列表
 * @returns {*}
 */
export function getAccountHHFaceHardwareConfigList() {
  return request({
    url: `/api/v1/auth/account/hhface/hardware/config/list`,
    method: 'post'
  })
}

/**
 * 查询HHFace权限配置-推送配置枚举列表
 * @returns {*}
 */
export function getAccountHHFacePushConfigList() {
  return request({
    url: `/api/v1/auth/account/hhface/push/config/list`,
    method: 'post'
  })
}

/**
 * 查询HHFace权限配置-功能配置枚举列表
 * @returns {*}
 */
export function getAccountHHFaceFuncConfigList() {
  return request({
    url: `/api/v1/auth/account/hhface/func/config/list`,
    method: 'post'
  })
}

/**
 * 查询HHFace权限配置-系统配置枚举列表
 * @returns {*}
 */
export function getAccountHHFaceSystemConfigList() {
  return request({
    url: `/api/v1/auth/account/hhface/system/config/list`,
    method: 'post'
  })
}

